@@ -41,14 +41,14 @@ from typing import Optional, Union
 
 from dimp import SymmetricKey, EncryptKey, ID, Meta, User
 from dimp import InstantMessage, SecureMessage, ReliableMessage
-from dimp import Content, FileContent
+from dimp import ContentType, Content, FileContent
 from dimp import Transceiver
 
 from .delegate import Callback, CompletionHandler
 from .delegate import MessengerDelegate
 from .facebook import Facebook
 
-from .cpu import ContentProcessor
+from .cpu import ContentProcessor, FileContentProcessor
 
 
 class Messenger(Transceiver):
@@ -123,7 +123,10 @@ class Messenger(Transceiver):
                     return item
 
     def __trim(self, msg: SecureMessage) -> Optional[SecureMessage]:
-        receiver = self.facebook.identifier(msg.envelope.receiver)
+        # check message delegate
+        if msg.delegate is None:
+            msg.delegate = self
+        receiver = msg.receiver
         user = self._select(receiver=receiver)
         if user is None:
             # current users not match
@@ -137,9 +140,12 @@ class Messenger(Transceiver):
     #  Transform
     #
     def verify_message(self, msg: ReliableMessage) -> Optional[SecureMessage]:
+        # check message delegate
+        if msg.delegate is None:
+            msg.delegate = self
         facebook = self.facebook
         # NOTICE: check meta before calling me
-        sender = facebook.identifier(msg.envelope.sender)
+        sender = msg.sender
         meta = msg.meta
         if meta is None:
             meta = facebook.meta(identifier=sender)
@@ -169,20 +175,15 @@ class Messenger(Transceiver):
     #
     #   InstantMessageDelegate
     #
-    def serialize_content(self, content: Content, key: dict, msg: InstantMessage) -> bytes:
-        password = SymmetricKey(key=key)
-        assert password == key, 'irregular symmetric key: %s' % key
+    def serialize_content(self, content: Content, key: SymmetricKey, msg: InstantMessage) -> bytes:
         # check attachment for File/Image/Audio/Video message content before
         if isinstance(content, FileContent):
-            data = password.encrypt(data=content.data)
-            # upload (encrypted) file data onto CDN and save the URL in message content
-            url = self.delegate.upload_data(data=data, msg=msg)
-            if url is not None:
-                content.url = url
-                content.data = None
-        return super().serialize_content(content=content, key=password, msg=msg)
+            fpu = self.__cpu.cpu(content_type=ContentType.File)
+            assert isinstance(fpu, FileContentProcessor), 'FPU error: %s' % fpu
+            fpu.upload(content=content, password=key, msg=msg)
+        return super().serialize_content(content=content, key=key, msg=msg)
 
-    def encrypt_key(self, data: bytes, receiver: str, msg: InstantMessage) -> Optional[bytes]:
+    def encrypt_key(self, data: bytes, receiver: ID, msg: InstantMessage) -> Optional[bytes]:
         facebook = self.facebook
         to = facebook.identifier(receiver)
         pk = facebook.public_key_for_encryption(identifier=to)
@@ -198,37 +199,27 @@ class Messenger(Transceiver):
     #
     #   SecureMessageDelegate
     #
-    def deserialize_content(self, data: bytes, key: dict, msg: SecureMessage) -> Optional[Content]:
-        password = SymmetricKey(key=key)
-        content = super().deserialize_content(data=data, key=password, msg=msg)
+    def deserialize_content(self, data: bytes, key: SymmetricKey, msg: SecureMessage) -> Optional[Content]:
+        content = super().deserialize_content(data=data, key=key, msg=msg)
         if content is None:
             return None
         # check attachment for File/Image/Audio/Video message content after
         if isinstance(content, FileContent):
-            i_msg = InstantMessage.new(content=content, envelope=msg.envelope)
-            # download from CDN
-            file_data = self.delegate.download_data(content.url, i_msg)
-            if file_data is None:
-                # save symmetric key for decrypted file data after download from CDN
-                content.password = password
-            else:
-                # decrypt file data
-                content.data = password.decrypt(data=file_data)
-                assert content.data is not None, 'failed to decrypt file data with key: %s' % key
-                content.url = None
+            fpu = self.__cpu.cpu(content_type=ContentType.File)
+            assert isinstance(fpu, FileContentProcessor), 'FPU error: %s' % fpu
+            fpu.download(content=content, password=key, msg=msg)
         return content
 
     #
     #   Send message
     #
-    def send_content(self, content: Content, receiver: ID, callback: Callback=None, split: bool=False) -> bool:
+    def send_content(self, content: Content, receiver: ID, callback: Callback=None) -> bool:
         """
         Send content to receiver
 
         :param content: message content
         :param receiver: receiver ID
         :param callback: callback function
-        :param split:    if it's a group message, split it before sending out
         :return: True on success
         """
         # Application Layer should make sure user is already login before it send message to server.
@@ -241,46 +232,34 @@ class Messenger(Transceiver):
         #     else:
         #         assert receiver == content.group, 'group ID not match: %s, %s' % (receiver, content)
         i_msg = InstantMessage.new(content=content, sender=user.identifier, receiver=receiver)
-        return self.send_message(msg=i_msg, callback=callback, split=split)
+        return self.send_message(msg=i_msg, callback=callback)
 
     def send_message(self, msg: Union[InstantMessage, ReliableMessage],
-                     callback: Callback=None, split: bool=False) -> bool:
+                     callback: Callback=None) -> bool:
         """
         Send instant message (encrypt and sign) onto DIM network
 
         :param msg:      instant message
         :param callback: callback function
-        :param split:    if it's a group message, split it before sending out
         :return:         False on data/delegate error
         """
         if isinstance(msg, ReliableMessage):
             return self.__send_message(msg=msg, callback=callback)
         elif not isinstance(msg, InstantMessage):
             raise TypeError('message error: %s' % msg)
-        facebook = self.facebook
+
         # Send message (secured + certified) to target station
         s_msg = self.encrypt_message(msg=msg)
+        if s_msg is None:
+            # public key not found?
+            # raise AssertionError('failed to encrypt message: %s' % msg)
+            return False
         r_msg = self.sign_message(msg=s_msg)
-        receiver = facebook.identifier(msg.envelope.receiver)
-        ok = True
-        if split and receiver.is_group:
-            # split for each members
-            members = facebook.members(identifier=receiver)
-            if members is None or len(members) == 0:
-                # FIXME: query group members from sender
-                messages = None
-            else:
-                messages = r_msg.split(members=members)
-            if messages is None:
-                # failed to split msg, send it to group
-                ok = self.__send_message(msg=r_msg, callback=callback)
-            else:
-                # sending group message one by one
-                for r_msg in messages:
-                    if not self.__send_message(msg=r_msg, callback=callback):
-                        ok = False
-        else:
-            ok = self.__send_message(msg=r_msg, callback=callback)
+        if r_msg is None:
+            # TODO: set iMsg.state = error
+            raise AssertionError('failed to sign message: %s' % s_msg)
+
+        ok = self.__send_message(msg=r_msg, callback=callback)
         # TODO: if OK, set iMsg.state = sending; else set iMsg.state = waiting
 
         if not self.save_message(msg=msg):
@@ -374,8 +353,11 @@ class Messenger(Transceiver):
         return self.encrypt_message(msg=i_msg)
 
     def __process_instant(self, instant: InstantMessage, msg: ReliableMessage) -> Optional[InstantMessage]:
-        facebook = self.facebook
-        sender = facebook.identifier(string=msg.envelope.sender)
+        # check message delegate
+        if instant.delegate is None:
+            instant.delegate = self
+        sender = instant.sender
+        receiver = instant.receiver
         # process content from sender
         res = self.process_content(content=instant.content, sender=sender, msg=msg)
         if not self.save_message(msg=instant):
@@ -385,7 +367,6 @@ class Messenger(Transceiver):
             # nothing to respond
             return None
         # check receiver
-        receiver = facebook.identifier(msg.envelope.receiver)
         user = self._select(receiver=receiver)
         assert user is not None, 'receiver error: %s' % receiver
         # pack message
